@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-VERSION = (1, 3, 8)  # PEP 386
+VERSION = (1, 3, 9)  # PEP 386
 __version__ = ".".join([str(x) for x in VERSION])
 
 from imgui.core import *  # noqa
@@ -201,7 +201,7 @@ TREE_NODE_COLLAPSING_HEADER = core.TREE_NODE_COLLAPSING_HEADER
 SLIDER_NONE = core.SLIDER_NONE
 #:  Clamp value to min/max bounds when input manually with CTRL+Click.
 #: By default CTRL+Click allows going out of bounds.
-SLIDER_CLAMP_ON_INPUT = core.SLIDER_CLAMP_ON_INPUT
+SLIDER_ALWAYS_CLAMP = core.SLIDER_ALWAYS_CLAMP
 #:  Make the widget logarithmic (linear otherwise). Consider using
 #: ImGuiSliderFlags_NoRoundToFormat with this if using a format-string
 #: with small amount of digits.
